SciDB-Py documentation — SciDB-Py 0.2 documentation

### Navigation

- index
- modules |
- modules |
- next |
- SciDB-Py 0.2 documentation »

# SciDB-Py documentation

SciDB-Py is a Python interface to the SciDB, the massively scalable array-oriented database. It provides an intuitive NumPy-like interface to SciDB, so that users can leverage powerful distributed, data-parallel scientific computing from the comfort of their Python interpreter.

- 1. Installing SciDB-Py
- 2. Getting Started
- 3. Class Reference
- 4. AFL Operator Reference

# Indices and tables

- Index
- Module Index
- Search Page

### Navigation

- index
- modules |
- modules |
- next |
- SciDB-Py 0.2 documentation »